//
//  DownMenuScrollView.m
//  CarInsurance
//
//  Created by HaiLai on 17/7/11.
//  Copyright © 2017年 HaiLai. All rights reserved.
//

#import "DownMenuScrollView.h"
#import "DownMenuHeader.h"
#import "UIView+Extension.h"

@interface DownMenuScrollView ()
@property (nonatomic,strong) NSMutableArray *itemSource;
@end

@implementation DownMenuScrollView
@synthesize dataSource,itemSource;

-(void)itemTap:(UIButton *)sender
{
    NSInteger index = sender.tag;
    [self select:index];
}

-(instancetype)initWithDataSource:(NSMutableArray *)datas
{
    if (self = [super init]) {
        dataSource = datas;
        [self refresh];
        self.showsHorizontalScrollIndicator = NO;
    }
    return self;
}

-(void)select:(NSInteger)index
{
    self.selectIndex = index;
    for (NSInteger i = 0; i < itemSource.count; i++) {
        DownMenuItem *item = itemSource[i];
        if (i == _selectIndex) {
            [item selected];
            [self show:item];
            CGPoint position;
            if (item.centerX >= self.width / 2 && self.contentSize.width - item.centerX >= self.width / 2) {
                 position = CGPointMake(item.centerX - self.width / 2, 0);
            }else if(item.centerX < self.width / 2) {
                position = CGPointMake(0, 0);
            }else {
                position = CGPointMake(self.contentSize.width - self.width, 0);
            }
            [self setContentOffset:position animated:YES];
        }else{
            [item unSelected];
            [self dismiss:item];
        }
    }
    if (_callback) {
        NSDictionary *info = dataSource[index];
        _callback(info,index);
    }
}

-(void)refresh
{
    for (UIView *view in self.subviews) {
        [view removeFromSuperview];
    }
    if (!itemSource) {
        itemSource = [[NSMutableArray alloc]init];
    }
    [self.itemSource removeAllObjects];
    
    for (NSInteger i = 0; i < dataSource.count; i++) {
        NSDictionary *dic = dataSource[i];
        DownMenuItem *item = [[DownMenuItem alloc]init];
        item.info = dic;
        item.tag = i;
        //添加点击事件
        [itemSource addObject:item];
    }
    
    [self layoutSubviews];
}

-(void)layoutSubviews
{
    [super layoutSubviews];
    
    if (self.height <= 0) {
        self.height = DefaultHeight;
        self.width = [[UIScreen mainScreen]bounds].size.width;
    }
    self.contentSize = CGSizeMake(MaginLeft + itemSource.count * (self.height + SpanH), self.height);
    
    for (NSInteger i = 0; i < itemSource.count; i++) {
        DownMenuItem *item = itemSource[i];
        item.height = self.height;
        item.width = self.height;
        item.x = MaginLeft + i * (item.width + SpanH);
        item.y = i != _selectIndex ? self.height / 2 : 0;
        [item addTarget:self action:@selector(itemTap:) forControlEvents:UIControlEventTouchUpInside];
        [self addSubview:item];
    }
}

-(void)show:(DownMenuItem *)item
{
    [UIView beginAnimations:nil context:nil];
    
    [UIView setAnimationDuration:0.3];
    
    [UIView setAnimationCurve:UIViewAnimationCurveEaseInOut];
    
    CGAffineTransform tranform1=CGAffineTransformMakeTranslation(0, -item.height / 2);
    
    item.transform =CGAffineTransformRotate(tranform1, 0);
    
    [UIView commitAnimations];
}

-(void)dismiss:(DownMenuItem *)item
{
    [UIView beginAnimations:nil context:nil];
    
    [UIView setAnimationDuration:0.3];
    
    [UIView setAnimationCurve:UIViewAnimationCurveEaseInOut];
    
    CGAffineTransform tranform1=CGAffineTransformMakeTranslation(0, 0);
    
    item.transform =CGAffineTransformRotate(tranform1, 0);
    
    [UIView commitAnimations];
}

/*
// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void)drawRect:(CGRect)rect {
    // Drawing code
}
*/

@end
